<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://biawp.ir
 * @since      1.0.0
 *
 * @package    Bw_gfed
 * @subpackage Bw_gfed/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Bw_gfed
 * @subpackage Bw_gfed/public
 * @author     Biawp <biawp.ir@gmail.com>
 */
class Bw_gfed_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/bw_gfed-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {}
	
	public function bw_gfed_callback ($atts) {
	    
	    ob_start();
	    
	    $entry_id = $atts['entryid'];
	    $form_id = $atts['formid'];
	    $template = $atts['template'];
	    
	    $form = GFAPI::get_form( $form_id );
	    $entry = GFAPI::get_entry( $entry_id );
	    
	    $count = 0;
		$field_count = sizeof( $form['fields'] );
		$has_product_fields = false;
		
		$content2 = '';
	    foreach ( $form['fields'] as $field ) {

			$content = $value = '';

			switch ( $field->get_input_type() ) {
				case 'section' :
					if ( ! GFCommon::is_section_empty( $field, $form, $entry ) ) {
						$count ++;
						$is_last = $count >= $field_count ? ' lastrow' : '';

						$content = '
                            <tr>
                                <td colspan="2" class="entry-view-section-break' . $is_last . '">' . esc_html( 'label' ) . '</td>
                            </tr>';
					}
					break;

				case 'captcha':
				case 'html':
				case 'password':
				case 'page':
					break;

				default :
					
					if ( GFCommon::is_product_field( $field->type ) ) {
						$has_product_fields = true;
						break;
					}

					$value = RGFormsModel::get_lead_field_value( $entry, $field );

					if ( is_array( $field->fields ) ) {
						
						$field->nestingLevel = 0;
					}

					$display_value = GFCommon::get_lead_field_display( $field, $value, $entry['currency'] );

					$display_value = apply_filters( 'gform_entry_field_value', $display_value, $field, $entry, $form );

					if ( ! empty( $display_value ) || $display_value === '0' ) {
						$count ++;
						$is_last  = $count >= $field_count && ! $has_product_fields ? true : false;
						$last_row = $is_last ? ' lastrow' : '';

						$display_value = empty( $display_value ) && $display_value !== '0' ? '&nbsp;' : $display_value;
                        
                        switch($template) {
                            case 1: 
                                $content = '
                                <tr class="template1">
                                    <td colspan="2" class="entry-view-field-name" style="background-color: #eaf2fa !important;">' . esc_html( GFCommon::get_label( $field ) ) . '</td>
                                </tr>
                                <tr class="template1">
                                    <td colspan="2" class="entry-view-field-value' . $last_row . '">' . $display_value . '</td>
                                </tr>';
                            break;
                            case 2:
                                $content = '
                                <tr class="template2">
                                    <td colspan="2" class="entry-view-field-name">' . esc_html( GFCommon::get_label( $field ) ) . '</td>
                                    <td colspan="2" class="entry-view-field-value' . $last_row . '">' . $display_value . '</td>
                                </tr>';
                            break;
                            case 3:
                                $content = '
                                <div class="template3">
                                    <strong colspan="2" class="entry-view-field-name">' . esc_html( GFCommon::get_label( $field ) ) . '</strong>
                                    <span colspan="2" class="entry-view-field-value' . $last_row . '">' . $display_value . '</span>
                                </div>';
                                echo '<style>.template3{ clear: both; } .entry-view-field-value ul{display: inline; float: left} .template3 strong{float: left; margin-right: 25px; padding: 10px;} .template3 span{display: inline-block; padding: 10px;}</style>';
                            break;
                                
                        }
					}
					break;
			}

			$content = gf_apply_filters( array( 'gform_field_content', $form['id'], $field->id ), $content, $field, $value, $entry['id'], $form['id'] );
		
	        $content2 .= $content;
	        
	    }
		
		return '<table class="bw_gfed_table"><tbody>' . $content2 . '</tbody></table>';
	    
	}

}
